/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: assignpayees.h 150 2005-02-23 02:15:34Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AQBANKING_KDE_ASSIGNPAYEES_H
#define AQBANKING_KDE_ASSIGNPAYEES_H


class KBanking;
class Transaction;
class QWidget;


#include "checkduplicates.ui.h"

class AssignPayees : public CheckDuplicatesUI {
  Q_OBJECT
private:
  KBanking *_app;
  bool _aborted;

public:
  AssignPayees(KBanking *kb,
               QWidget* parent=0,
               const char* name=0,
               WFlags fl=0);
  ~AssignPayees();

  bool assign();

public slots:
  void slotAbortClicked();

};







#endif


